Na tej stronie

zabbix_sender

ZABBIX_SENDER(1)            Podręcznik poleceń ogólnych           ZABBIX_SENDER(1)

NAZWA
       zabbix_sender - narzędzie zabbix_sender

SKŁADNIA
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

OPIS
       zabbix_sender to narzędzie wiersza poleceń służące do wysyłania danych
       monitorowania do serwera Zabbix lub proxy. Na serwerze Zabbix należy
       utworzyć pozycję typu Zabbix trapper z odpowiednim kluczem. Należy
       pamiętać, że wartości przychodzące będą akceptowane wyłącznie z hostów
       określonych w polu Allowed hosts tej pozycji.

OPCJE
       -c, --config config-file
              Użyj config-file. zabbix_sender odczytuje szczegóły serwera z
              pliku konfiguracyjnego agentd. Domyślnie zabbix_sender nie
              odczytuje żadnego pliku konfiguracyjnego. Obsługiwane są tylko
              parametry Hostname, ServerActive, SourceIP, TLSConnect,
              TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity
              i TLSPSKFile. Hostname zdefiniowany za pomocą parametru
              HostnameItem nie zostanie pobrany; w takim przypadku nazwę hosta
              należy określić w wierszu poleceń (zobacz opcję -s). Wszystkie
              adresy zdefiniowane w parametrze konfiguracyjnym ServerActive
              agenta są używane do wysyłania danych. Jeśli wysyłanie danych
              wsadowych do jednego adresu nie powiedzie się, kolejne wsady nie
              są wysyłane na ten adres.

       -z, --zabbix-server server
              Nazwa hosta lub adres IP serwera Zabbix. Jeśli host jest
              monitorowany przez proxy, należy użyć nazwy hosta lub adresu IP
              proxy. Użycie razem z opcją --config powoduje zastąpienie wpisów
              parametru ServerActive określonych w pliku konfiguracyjnym agentd.

       -p, --port port
              Określ numer portu, na którym działa trapper serwera Zabbix.
              Wartość domyślna to 10051. Użycie razem z opcją --config
              powoduje zastąpienie wpisów portów parametru ServerActive
              określonych w pliku konfiguracyjnym agentd.

       -I, --source-address IP-address
              Określ źródłowy adres IP. Użycie razem z opcją --config powoduje
              zastąpienie parametru SourceIP określonego w pliku
              konfiguracyjnym agentd.

       -t, --timeout seconds
              Określ limit czasu. Dozwolony zakres: 1-300 sekund (domyślnie:
              60).

       -s, --host host
              Określ nazwę hosta, do którego należy pozycja (zarejestrowaną
              w frontend Zabbix). Adres IP hosta ani nazwa DNS nie będą
              działać. Użycie razem z opcją --config powoduje zastąpienie
              parametru Hostname określonego w pliku konfiguracyjnym agentd.

       -k, --key key
              Określ klucz pozycji, do której ma zostać wysłana wartość.

       -o, --value value
              Określ wartość pozycji.

       -i, --input-file input-file
              Wczytaj wartości z pliku wejściowego. Określ - jako <input-file>,
              aby odczytywać wartości ze standardowego wejścia. Każdy wiersz
              pliku zawiera elementy rozdzielone białymi znakami:
              <hostname> <key> <value>. Każda wartość musi być określona
              w osobnym wierszu. Każdy wiersz musi zawierać 3 elementy
              rozdzielone białymi znakami: <hostname> <key> <value>, gdzie
              „hostname” to nazwa monitorowanego hosta zarejestrowana
              w frontend Zabbix, „key” to docelowy klucz pozycji, a „value”
              to wartość do wysłania. Określ - jako <hostname>, aby użyć nazwy
              hosta z pliku konfiguracyjnego agenta lub z argumentu --host.

              Przykład wiersza pliku wejściowego:

               "Linux DB3" db.connections 43

              Typ wartości musi być prawidłowo ustawiony w konfiguracji pozycji
              w frontend Zabbix. zabbix_sender wyśle do 250 wartości w ramach
              jednego połączenia. Zawartość pliku wejściowego musi być zakodowana
              w UTF-8. Wszystkie wartości z pliku wejściowego są wysyłane
              sekwencyjnie, od góry do dołu. Wpisy muszą być sformatowane zgodnie
              z następującymi zasadami:

                     • Obsługiwane są wpisy ujęte w cudzysłowy i nieujęte
                       w cudzysłowy.

                     • Znakiem cytowania jest cudzysłów.

                     • Wpisy zawierające białe znaki muszą być ujęte
                       w cudzysłowy.

                     • Znaki cudzysłowu i ukośnika odwrotnego wewnątrz wpisu
                       ujętego w cudzysłowy muszą być poprzedzone ukośnikiem
                       odwrotnym.

                     • Wpisy nieujęte w cudzysłowy nie obsługują znaków
                       ucieczki.

                     • Sekwencje ucieczki znaku nowego wiersza (\n) są
                       obsługiwane w ciągach ujętych w cudzysłowy.

                     • Sekwencje ucieczki znaku nowego wiersza są usuwane
                       z końca wpisu.

       -T, --with-timestamps
              Tej opcji można używać wyłącznie z opcją --input-file.

              Każdy wiersz pliku wejściowego musi zawierać 4 elementy rozdzielone
              białymi znakami: <hostname> <key> <timestamp> <value>. Znacznik
              czasu należy określić w formacie znacznika czasu Unix. Jeśli
              docelowa pozycja ma odwołujące się do niej wyzwalacze, wszystkie
              znaczniki czasu muszą być rosnące, w przeciwnym razie obliczanie
              zdarzeń nie będzie prawidłowe.

              Przykład wiersza pliku wejściowego:

               "Linux DB3" db.connections 1429533600 43

              Więcej informacji zawiera opis opcji --input-file.

              Jeśli wartość ze znacznikiem czasu zostanie wysłana dla hosta,
              który znajduje się w okresie utrzymania typu „no data”, wartość
              ta zostanie odrzucona; można jednak wysłać wartość ze znacznikiem
              czasu przypadającym na zakończony okres utrzymania i zostanie ona
              zaakceptowana.

       -N, --with-ns
              Tej opcji można używać wyłącznie z opcją --with-timestamps.

              Każdy wiersz pliku wejściowego musi zawierać 5 elementów
              rozdzielonych białymi znakami: <hostname> <key> <timestamp> <ns>
              <value>.

              Przykład wiersza pliku wejściowego:

               "Linux DB3" db.connections 1429533600 7402561 43

              Więcej informacji zawiera opis opcji --input-file.

       -r, --real-time
              Wysyłaj wartości pojedynczo, natychmiast po ich otrzymaniu.
              Można tego używać podczas odczytu ze standardowego wejścia.

       --tls-connect value
              Sposób łączenia z serwerem lub proxy. Wartości:

                   unencrypted
                               połącz bez szyfrowania (domyślnie)

                   psk         połącz za pomocą TLS i klucza wstępnie
                               współdzielonego

                   cert        połącz za pomocą TLS i certyfikatu

       --tls-ca-file CA-file
              Pełna ścieżka do pliku zawierającego certyfikaty najwyższego
              poziomu CA do weryfikacji certyfikatu peera.

       --tls-crl-file CRL-file
              Pełna ścieżka do pliku zawierającego unieważnione certyfikaty.

       --tls-server-cert-issuer cert-issuer
              Dozwolony wystawca certyfikatu serwera.

       --tls-server-cert-subject cert-subject
              Dozwolony podmiot certyfikatu serwera.

       --tls-cert-file cert-file
              Pełna ścieżka do pliku zawierającego certyfikat lub łańcuch
              certyfikatów.

       --tls-key-file key-file
              Pełna ścieżka do pliku zawierającego klucz prywatny.

       --tls-psk-identity PSK-identity
              Ciąg identyfikatora PSK.

       --tls-psk-file PSK-file
              Pełna ścieżka do pliku zawierającego klucz wstępnie współdzielony.

       --tls-cipher13 cipher-string
              Ciąg szyfru dla OpenSSL 1.1.1 lub nowszego dla TLS 1.3.
              Zastępuje domyślne kryteria wyboru zestawu szyfrów. Ta opcja
              nie jest dostępna, jeśli wersja OpenSSL jest starsza niż 1.1.1.

       --tls-cipher cipher-string
              Ciąg priorytetów GnuTLS (dla TLS 1.2 i nowszych) lub ciąg szyfru
              OpenSSL (tylko dla TLS 1.2). Zastępuje domyślne kryteria wyboru
              zestawu szyfrów.

       -v, --verbose
              Tryb szczegółowy; -vv wyświetla więcej informacji.

       -h, --help
              Wyświetl tę pomoc i zakończ działanie.

       -V, --version
              Wyświetl informacje o wersji i zakończ działanie.

KOD ZAKOŃCZENIA
       Kod zakończenia wynosi 0, jeśli wartości zostały wysłane i wszystkie
       zostały pomyślnie przetworzone przez serwer. Jeśli dane zostały wysłane,
       ale przetwarzanie co najmniej jednej wartości nie powiodło się, kod
       zakończenia wynosi 2. Jeśli wysyłanie danych nie powiodło się, kod
       zakończenia wynosi 1.

PRZYKŁADY
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Wyślij 342.45 jako wartość pozycji mysql.queries monitorowanego
              hosta. Użyj monitorowanego hosta i serwera Zabbix zdefiniowanych
              w pliku konfiguracyjnym agenta.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Wyślij 342.45 jako wartość pozycji mysql.queries hosta Monitored
              Host, używając serwera Zabbix zdefiniowanego w pliku
              konfiguracyjnym agenta.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Wyślij wartości z pliku data_values.txt do serwera Zabbix
              o adresie IP 192.168.1.113. Nazwy hostów i klucze są zdefiniowane
              w pliku.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Wyślij wartość ze znacznikiem czasu z wiersza poleceń do serwera
              Zabbix określonego w pliku konfiguracyjnym agenta. Myślnik
              w danych wejściowych oznacza, że nazwa hosta również powinna
              zostać użyta z tego samego pliku konfiguracyjnego.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Wyślij pustą wartość pozycji do serwera Zabbix o adresie IP
              192.168.1.113 na porcie 10000 z wiersza poleceń. Puste wartości
              należy oznaczać pustymi cudzysłowami.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Wyślij 342.45 jako wartość pozycji mysql.queries hosta Monitored
              Host do serwera o adresie IP 192.168.1.113, używając TLS
              z certyfikatem.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Wyślij 342.45 jako wartość pozycji mysql.queries hosta Monitored
              Host do serwera o adresie IP 192.168.1.113, używając TLS
              z kluczem wstępnie współdzielonym (PSK).

ZOBACZ TAKŻE
       Dokumentacja

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)